
static char help[] = "Demonstrates a bug in VecLoad.\n\n";


#include <petscdm.h>
#include <petscdmda.h>
#include <petscvec.h>
#include <petscviewerhdf5.h>


int main(int argc,char **argv)
{
  Vec            u, v;
  DM             da;
  PetscViewer    viewer;
  PetscErrorCode ierr;
  PetscInt       m = 10, n = 10, dof = 2;

  ierr = PetscInitialize(&argc,&argv,(char*)0,help);CHKERRQ(ierr);

  ierr = DMDACreate2d(PETSC_COMM_WORLD, DM_BOUNDARY_NONE, DM_BOUNDARY_NONE,DMDA_STENCIL_BOX,m,n,PETSC_DECIDE,PETSC_DECIDE,dof,1,0,0,&da);CHKERRQ(ierr);
  
  ierr = DMCreateGlobalVector(da, &u);CHKERRQ(ierr);
  ierr = DMCreateGlobalVector(da, &v);CHKERRQ(ierr);
  
  ierr = PetscObjectSetName((PetscObject) u, "u");CHKERRQ(ierr);
  ierr = PetscObjectSetName((PetscObject) v, "v");CHKERRQ(ierr);
  
  ierr = PetscViewerHDF5Open(PETSC_COMM_WORLD, "input.h5", FILE_MODE_READ, &viewer);CHKERRQ(ierr);
  
  
  // This test is all about how VecLoad obey the group setting, so let's set
  // this for all tests.
  ierr = PetscViewerHDF5PushGroup(viewer, "/FIELDS");CHKERRQ(ierr);
  
  
  // Test 1: Try to load the vector u. This vector is located in the root of
  // the HDF5 file, and THIS SHOULD FAIL if everything works (PETSc should
  // look in the /FIELDS group...
  ierr = VecLoad(u, viewer);CHKERRQ(ierr);
  
  
  // Test 2: Try to load the vector v. This vector is located in the /FIELDS
  // group of the HDF5 file, and THIS SHOULD WORK. However, it doesn't...
  ierr = VecLoad(v, viewer);CHKERRQ(ierr);
  
  
  
  ierr = PetscViewerDestroy(&viewer);CHKERRQ(ierr);
  ierr = VecDestroy(&v);CHKERRQ(ierr);
  ierr = VecDestroy(&u);CHKERRQ(ierr);
  ierr = DMDestroy(&da);CHKERRQ(ierr);
  ierr = PetscFinalize();
  return 0;
}


